@@ -135,6 +135,27 @@ SCALE_CARD_SAT = (0.17, 1.0)
 SCALE_CARD_VAL = (0.25, 0.75)
 
 
+
+def pixel_volume_to_circular_area(pixels: int, scale: float) -> float:
+    """helps work out the area of a circular object with a similar pixel volume at the same scale
+    pixels = pixels in the object , scale = pixels per cm in this image, obtainable from rp.griffin_scale_card()
+
+    returns a float giving the area a circle of that number of pixels would take up
+    """
+
+    i = 1
+    r = 0
+    while i < pixels / 2.0:
+        i = i + (i + 2)
+        r += 1
+    r =  r / scale
+    return math.pi * (r**2)
+
+
+
+
+
+
 def threshold_hsv_img(im: np.ndarray,
                       h: Tuple[float, float] = HEALTHY_HUE,
                       s: Tuple[float, float] = HEALTHY_SAT,
@@ -452,7 +473,7 @@ def griffin_lesion_centres(hsv_img, lesion_region: measure._regionprops._RegionP
     sub_img = get_region_subimage(lesion_region, img_grey)
     edges = feature.canny(sub_img, sigma=sigma).astype(int)
     mask = ndi.binary_fill_holes(edges)
-    labelled_image, count = label_image(mask)
+    labelled_image, _ = label_image(mask)
     region_props = get_object_properties(labelled_image, edges)
     return region_props
 
@@ -461,13 +482,14 @@ def griffin_scale_card(hsv_img, h, s, v, side_length=5):
     '''returns pixels per cm of scale card object'''
     mask = threshold_hsv_img(hsv_img, h=h, s=s, v=v).astype(int)
     card_mask = ndi.binary_fill_holes(mask)
-    labelled_image, count = label_image(card_mask)
+    labelled_image, _ = label_image(card_mask)
     region_props = get_object_properties(labelled_image, card_mask)
+    plt.imshow(card_mask)
     if len(region_props) > 0:
         biggest_obj_area = sorted(region_props, key=lambda rp: rp.area, reverse=True)[0].area  # assume biggest object is scale card
         side = math.sqrt(biggest_obj_area)
         return side / float(side_length)
-    return 0.0
+    return None
 
 
 def clear_background(img: np.ndarray, mask: np.ndarray) -> np.ndarray:
